/**
  ******************************************************************************
  * @file           : main.c
  * @author         : sinomcu.com-AE
  * @brief          : Main program body
  *    
  *          This file provides example code for TIM1 and TIM3 synchronization and 
  * printf by uart,LED1 Toggle defualt period 0.5s.
  * For details, see "readme.txt"    
  *         
  ******************************************************************************
   * @attention 
  *                           DISCLAIMER
  * The present firmware which is for guidance only aims at providing customers
  * with coding information regarding their products in order for them to save
  * time. As a result, sinomcu.com shall not be held liable for any direct,indirect
  * or consequential damages with respect to any claims arising from the content 
  * of such firmware and/or the use made by customers of the coding information 
  * contained herein in connection with their products.
  *
  * <h2><center>&copy; Copyright (c) 2021 sinomcu.com All rights reserved.</center></h2>
  *
  ******************************************************************************
  */  
  
#include "system_define.h"

#define COUNT_PERIOD    500       // unit ms

/**
  * @brief  Main program
  * @param  None
  * @retval None
  */
int main(void) {
  uint32_t count = 0;
    
  sysclk_init();                  // sysclk 48M,HSI/2 *12;if not call this function,default HSI 8M
  SystemCoreClockUpdate();        // get System Core Clock
    
  sys_tick_init();
  gpio_init();
#if(defined(EN_PRINT_UART) && EN_PRINT_UART)  
  MS32_RCC_SetUSARTClockSource(MS32_RCC_USART1_CLKSOURCE_HSI);  // uart clk HSI 8M  
  usart1_uart_init(115200);
#endif
  timer1_pwm_init();
  timer3_pwm_init();
  MS32_TIM_EnableCounter(TIM1); 
#if (TIMER_SYNC_MODE == TIM1_TIM3_INDEPENDENT)   
  MS32_TIM_EnableCounter(TIM3);
#endif  
  LED1_ON(); 

#if (TIMER_SYNC_MODE == TIM1_TIM3_INDEPENDENT) 
  printf("\r\n\r\n*****TIM1 TIM3 Independent*****");
#elif (TIMER_SYNC_MODE == TIM1_UPDATE_TO_TIM3) 
  printf("\r\n\r\n*****TIM1(Master) Upate to TIM3(Slave)*****");
#elif (TIMER_SYNC_MODE == TIM1_OC4REF_PWM1_TO_TIM3) 
  printf("\r\n\r\n*****TIM1(Master) OC4REF PWM1 TIM3(Slave)*****");
#else    //TIM1_OC4REF_PWM2_TO_TIM3
  printf("\r\n\r\n*****TIM1(Master) OC4REF PWM2 TIM3(Slave)*****");
#endif
  printf("\r\n--Inf:System Core Clock %d Hz.",SystemCoreClock);
    
  Start_User_MS_SF_Timer(COUNT_PERIOD);
  while(1) {
    if(Get_State_User_MS_SF_Timer() == SF_TIMER_OV) {
      Start_User_MS_SF_Timer(COUNT_PERIOD);                // clear soft timer ov
      LED1_TOGGLE();
      count++;
      printf("\r\n--Inf: running count:%d",count);
    }
  }
}

/**
  * @brief  SystemClock_Config HSI/2 to PLL*12 sysclk 48M
  * @param  None
  * @retval None
  */
void sysclk_init(void) {
  MS32_RCC_OscInitTypeDef osc_cfg;
  MS32_RCC_PllInitTypeDef pll_cfg;
  MS32_RCC_ClkInitTypeDef clk_cfg;

  // get and clear reset flag 
  MS32_RCC_GetResetFlag(ENABLE);
  
  // osc config 
  osc_cfg.HSIState = MS32_RCC_HSI_ON;
  osc_cfg.HSEState = MS32_RCC_HSE_OFF;
  osc_cfg.LSIState = MS32_RCC_LSI_OFF;
//  osc_cfg.LSEState = MS32_RCC_LSE_ON_DRV_H;
  MS32_RCC_OscConfig(&osc_cfg);
  
  // pll config 
  pll_cfg.PLLState  = MS32_RCC_PLL_ON;
  pll_cfg.PLLSource = MS32_RCC_PLL_SOURCE_HSI_DIV_2;       // HSI/2 4M
  pll_cfg.PLLMUL    = MS32_RCC_PLL_MUL12;
  pll_cfg.PREDIV    = MS32_RCC_PLL_PREDIV_DIV1;
  MS32_RCC_PllConfig(&pll_cfg);
  
  // sysclk config 
  clk_cfg.SYSCLKSource   = MS32_RCC_SYSCLK_SOURCE_PLL;
  clk_cfg.AHBCLKDivider  = MS32_RCC_SYSCLK_DIV1;
  clk_cfg.APB1CLKDivider = MS32_RCC_HCLK_DIV1;
  MS32_RCC_ClockConfig(&clk_cfg);
}

/******************************** END OF FILE *********************************/
